tiled.client.array.ArrayClient
==============================

.. currentmodule:: tiled.client.array

.. autoclass:: ArrayClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ArrayClient.__init__
      ~ArrayClient.download
      ~ArrayClient.export
      ~ArrayClient.new_variation
      ~ArrayClient.read
      ~ArrayClient.read_block
      ~ArrayClient.refresh
      ~ArrayClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ArrayClient.context
      ~ArrayClient.dims
      ~ArrayClient.formats
      ~ArrayClient.item
      ~ArrayClient.metadata
      ~ArrayClient.offline
      ~ArrayClient.path
      ~ArrayClient.uri
      ~ArrayClient.username
   
   